==> foundation-core-app-1.6.0.tgz: package/common/utils/content-stack-utils.ts <==
import ContentStackLivePreview from '@contentstack/live-preview-utils';
import { IStackSdk } from '@contentstack/live-preview-utils/dist/src/utils/types';
import * as ContentStackSDK from 'contentstack';
import { GetServerSidePropsContext } from 'next';

import referenceMap from '../nuskin-content-stack/reference-map';
import { getEnvironmentValues } from './env-utils';

const SITE_PROPERTIES = 'site_properties';

export const ContentStackEnv = getEnvironmentValues();

const {
    CONTENT_STACK_API_KEY,
    CONTENT_STACK_DELIVERY_TOKEN,
    CONTENT_STACK_ENVIRONMENT,
    CONTENT_STACK_REGION,
    CONTENT_STACK_MANAGEMENT_TOKEN,
    CONTENT_STACK_API_HOST,
    CONTENT_STACK_LIVE_PREVIEW,
    APP_ENV
} = ContentStackEnv;

const stackOptions: ContentStackSDK.Config = {
    api_key: CONTENT_STACK_API_KEY || '',
    delivery_token: CONTENT_STACK_DELIVERY_TOKEN || '',
    environment: CONTENT_STACK_ENVIRONMENT || '',
    region: CONTENT_STACK_REGION as ContentStackSDK.Region,
    live_preview: {
        enable: CONTENT_STACK_LIVE_PREVIEW === 'true' || false,
        management_token: CONTENT_STACK_MANAGEMENT_TOKEN || '',
        host: CONTENT_STACK_API_HOST || ''
    }
};

const Stack = ContentStackSDK.Stack(stackOptions);
ContentStackLivePreview.init({
    stackSdk: Stack as unknown as IStackSdk,
    clientUrlParams: {
        host: ContentStackEnv.CONTENT_STACK_APP_HOST
    },
    ssr: false,
    enable: CONTENT_STACK_LIVE_PREVIEW === 'true',
    cleanCslpOnProduction: true
});

if (ContentStackEnv?.CONTENT_STACK_API_HOST) {
    Stack.setHost(ContentStackEnv.CONTENT_STACK_API_HOST);
}

export const languageMap: Record<string, string> = {
    'en-us': 'en',
    'es-us': 'US-es',
    'vi-us': 'US-vi',
    'zh-us': 'US-zh',
    'en-ca': 'CA-en',
    'zh-ca': 'CA-zh'
};

export const getLivePreviewContent = async (
    pageName: string,
    languageCode: string,
    pathname: string,
    domain: string,
    refs: string[]
) => {
    return getPageContent(pageName, languageCode, pageName, domain, refs);
};

export const getDomainAndLocale = (context: GetServerSidePropsContext) => {
    const { query } = context;
    const domain = context?.req?.headers?.host || '';
    const language = query?.['language'] || 'en';
    const region = (query?.['region'] || 'us') as string;

    const languageCode = `${language}-${region}`;
    const locale = `${language}_${region.toUpperCase()}` || 'en_US';
    return { domain, locale, languageCode };
};

export const getPageContent = async (
    pageName: string,
    languageCode: string,
    pathname: string,
    domain: string,
    refs: string[] = referenceMap.ns_page
) => {
    try {
        /*
         * includeFallback will pull the page content from the fallback language configured in contentstack
         * incase the request locale is not published in Content stack
         */
        const entry = Stack.ContentType(pageName)
            .Query()
            .language(languageMap[languageCode] || languageCode)
            .includeFallback();
        entry.includeReference(refs);
        entry.includeOwner().toJSON();
        const siteQuery = Stack.ContentType('site_properties')
            .Query()
            .where(`${APP_ENV}_domain_name`, domain);
        return await entry.referenceIn(SITE_PROPERTIES, siteQuery).where('url', pathname).findOne();
    } catch (e) {
        console.error(e);
        return null;
    }
};

export const getContentTypeData = async (uid: string, refs: string[] = []) => {
    try {
        return await Stack.ContentType(uid).Query().includeReference(refs).toJSON().findOne();
    } catch (e) {
        console.error(e);
        return null;
    }
};

export const extractContentType = (block: any) => Object.keys(block || {})?.[0];
export const { onEntryChange } = ContentStackLivePreview;

export default Stack;

==> foundation-core-app-1.11.3.tgz: package/common/utils/content-stack-utils.ts <==
import ContentStackLivePreview from '@contentstack/live-preview-utils';
import { IStackSdk } from '@contentstack/live-preview-utils/dist/src/utils/types';
import * as ContentStackSDK from 'contentstack';
import { GetServerSidePropsContext } from 'next';

import referenceMap from '../nuskin-content-stack/reference-map';
import { getEnvironmentValues } from './env-utils';

const SITE_PROPERTIES = 'site_properties';

export const ContentStackEnv = getEnvironmentValues();

const {
    CONTENT_STACK_API_KEY,
    CONTENT_STACK_DELIVERY_TOKEN,
    CONTENT_STACK_ENVIRONMENT,
    CONTENT_STACK_REGION,
    CONTENT_STACK_MANAGEMENT_TOKEN,
    CONTENT_STACK_API_HOST,
    CONTENT_STACK_LIVE_PREVIEW,
    APP_ENV
} = ContentStackEnv;

const stackOptions: ContentStackSDK.Config = {
    api_key: CONTENT_STACK_API_KEY || '',
    delivery_token: CONTENT_STACK_DELIVERY_TOKEN || '',
    environment: CONTENT_STACK_ENVIRONMENT || '',
    region: CONTENT_STACK_REGION as ContentStackSDK.Region,
    live_preview: {
        enable: CONTENT_STACK_LIVE_PREVIEW === 'true' || false,
        management_token: CONTENT_STACK_MANAGEMENT_TOKEN || '',
        host: CONTENT_STACK_API_HOST || ''
    }
};

const Stack = ContentStackSDK.Stack(stackOptions);
ContentStackLivePreview.init({
    stackSdk: Stack as unknown as IStackSdk,
    clientUrlParams: {
        host: ContentStackEnv.CONTENT_STACK_APP_HOST
    },
    ssr: false,
    enable: CONTENT_STACK_LIVE_PREVIEW === 'true',
    cleanCslpOnProduction: true
});

if (ContentStackEnv?.CONTENT_STACK_API_HOST) {
    Stack.setHost(ContentStackEnv.CONTENT_STACK_API_HOST);
}

export const languageMap: Record<string, string> = {
    'en-us': 'en',
    'es-us': 'US-es',
    'vi-us': 'US-vi',
    'zh-us': 'US-zh',
    'en-ca': 'CA-en',
    'zh-ca': 'CA-zh',
    'en-in': 'IN-en',
    'fr-ca': 'CA-fr',
};

export const getLivePreviewContent = async (
    pageName: string,
    languageCode: string,
    pathname: string,
    domain: string,
    refs: string[]
) => {
    return getPageContent(pageName, languageCode, pageName, domain, refs);
};

export const getDomainAndLocale = (context: GetServerSidePropsContext) => {
    const { query } = context;
    const domain = context?.req?.headers?.host || '';
    const language = query?.['language'] || 'en';
    const region = (query?.['region'] || 'us') as string;

    const languageCode = `${language}-${region}`;
    const locale = `${language}_${region.toUpperCase()}` || 'en_US';
    return { domain, locale, languageCode };
};

export const getPageContent = async (
    pageName: string,
    languageCode: string,
    pathname: string,
    domain: string,
    refs: string[] = referenceMap.ns_page
) => {
    try {
        /*
         * includeFallback will pull the page content from the fallback language configured in contentstack
         * incase the request locale is not published in Content stack
         */
        const entry = Stack.ContentType(pageName)
            .Query()
            .language(languageMap[languageCode] || languageCode)
            .includeFallback();
        entry.includeReference(refs);
        entry.includeOwner().toJSON();
        const siteQuery = Stack.ContentType('site_properties').Query().where(`${APP_ENV}_domain_name`, domain);
        return await entry.referenceIn(SITE_PROPERTIES, siteQuery).where('url', pathname).findOne();
    } catch (e) {
        console.error(e);
        return null;
    }
};

export const getContentTypeData = async (uid: string, refs: string[] = []) => {
    try {
        return await Stack.ContentType(uid).Query().includeReference(refs).toJSON().findOne();
    } catch (e) {
        console.error(e);
        return null;
    }
};

export const extractContentType = (block: any) => Object.keys(block || {})?.[0];
export const { onEntryChange } = ContentStackLivePreview;

export default Stack;
